Class: Google::Shopping::Merchant::Accounts::V1::CreateAndConfigureAccountRequest::SetAliasForRelationship
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Accounts::V1::CreateAndConfigureAccountRequest::SetAliasForRelationship
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/accounts/v1/accounts.rb
Overview
Set an alias for a relationship between a provider and the account to be created.
Instance Attribute Summary collapse
-
#account_id_alias ⇒ ::String
Required.
-
#provider ⇒ ::String
Required.
Instance Attribute Details
#account_id_alias ⇒ ::String
Returns Required. The unique ID of this account in the provider's system. The value must be unique across all accounts on the platform for this provider.
208 209 210 211 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/accounts.rb', line 208 class SetAliasForRelationship include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#provider ⇒ ::String
Returns Required. The provider of the service. This is a reference to an account
such as providers/123 or accounts/123. The same provider must be
specified in at least one of the service fields.
208 209 210 211 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/accounts.rb', line 208 class SetAliasForRelationship include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |