Class: Google::Shopping::Merchant::Accounts::V1::CreateTestAccountRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/accounts/v1/accounts.rb

Overview

Request message for the CreateTestAccount RPC

Instance Attribute Summary collapse

Instance Attribute Details

#account::Google::Shopping::Merchant::Accounts::V1::Account

Returns Required. The account to be created.

Returns:



222
223
224
225
# File 'proto_docs/google/shopping/merchant/accounts/v1/accounts.rb', line 222

class CreateTestAccountRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The account resource name to create the test account under. Format: accounts/{account}.

Returns:

  • (::String)

    Required. The account resource name to create the test account under. Format: accounts/{account}



222
223
224
225
# File 'proto_docs/google/shopping/merchant/accounts/v1/accounts.rb', line 222

class CreateTestAccountRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end