Class: Google::Shopping::Merchant::Accounts::V1::DeliveryTime
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::Accounts::V1::DeliveryTime
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb
Overview
Time spent in various aspects from order to the delivery of the product.
Instance Attribute Summary collapse
-
#cutoff_time ⇒ ::Google::Shopping::Merchant::Accounts::V1::CutoffTime
Business days cutoff time definition.
-
#handling_business_day_config ⇒ ::Google::Shopping::Merchant::Accounts::V1::BusinessDayConfig
The business days during which orders can be handled.
-
#max_handling_days ⇒ ::Integer
Maximum number of business days spent before an order is shipped.
-
#max_transit_days ⇒ ::Integer
Maximum number of business days that is spent in transit.
-
#min_handling_days ⇒ ::Integer
Minimum number of business days spent before an order is shipped.
-
#min_transit_days ⇒ ::Integer
Minimum number of business days that is spent in transit.
-
#transit_business_day_config ⇒ ::Google::Shopping::Merchant::Accounts::V1::BusinessDayConfig
The business days during which orders can be in-transit.
-
#transit_time_table ⇒ ::Google::Shopping::Merchant::Accounts::V1::TransitTable
Transit time table, number of business days spent in transit based on row and column dimensions.
-
#warehouse_based_delivery_times ⇒ ::Array<::Google::Shopping::Merchant::Accounts::V1::WarehouseBasedDeliveryTime>
Optional.
Instance Attribute Details
#cutoff_time ⇒ ::Google::Shopping::Merchant::Accounts::V1::CutoffTime
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#handling_business_day_config ⇒ ::Google::Shopping::Merchant::Accounts::V1::BusinessDayConfig
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_handling_days ⇒ ::Integer
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#max_transit_days ⇒ ::Integer
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_handling_days ⇒ ::Integer
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_transit_days ⇒ ::Integer
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transit_business_day_config ⇒ ::Google::Shopping::Merchant::Accounts::V1::BusinessDayConfig
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#transit_time_table ⇒ ::Google::Shopping::Merchant::Accounts::V1::TransitTable
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#warehouse_based_delivery_times ⇒ ::Array<::Google::Shopping::Merchant::Accounts::V1::WarehouseBasedDeliveryTime>
380 381 382 383 |
# File 'proto_docs/google/shopping/merchant/accounts/v1/shippingsettings.rb', line 380 class DeliveryTime include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |